/**
 * This file demonstrates the ability to command settings to a group.
 */

#include <stdio.h>
#include <math.h>

#include "hebi_lookup.h"
#include "hebi_group_command.h"
#include "hebi_command.h"
#include "hebi_mac_address.h"
#include "lookup_helpers.c"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  int numModules = hebiGroupGetNumberOfModules(group);

  // Create a command object; this can be sent to the group
  HebiGroupCommandPtr command = hebiGroupCommandCreate(numModules);
  if (command == NULL)
  {
    printf("Could not create command object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // Set the name for all the modules
  int new_strategy = 2;
  int module_index;
  for (module_index = 0; module_index < numModules; module_index++)
  {
    // We get the command for this particular module
    HebiCommandPtr module_cmd = hebiGroupCommandGetModuleCommand(command, module_index);
    // Set the strategy for this module (note -- we don't save the control strategy here!)
    hebiCommandSetEnum(module_cmd, CommandEnumControlStrategy, new_strategy);
  }

  long timeout_ms = 100;
  if (hebiGroupSendCommandWithAcknowledgement(group, command, timeout_ms) == 0)
  {
    printf("Got acknowledgement.\n");
  }
  else
  {
    printf("Did not receive acknowledgement!\n");
  }

  // We must release the resources back to the library when done!
  hebiGroupCommandRelease(command);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
