/**
 * This file demonstrates the group lookup capabilities of the API. The lookup
 * allows you to create groups of modules based on which ones are available on
 * the network.
 */

#include <stdio.h>
#include <string.h>
#include "hebi.h"
#include "hebi_util.h"

/**
 * Attempts to look for several groups on the network (hardcoded addresses below),
 * and retrieve references to them.
 */
int main()
{
  // Create the lookup object
  HebiLookupPtr lookup = hebiLookupCreate();
  if (lookup == NULL)
  {
    printf("createLookup() returned NULL.\n\n");
    hebiCleanup();
    return 1;
  }

  // Wait for the module list to populate, and print out its contents
  hebi_sleep_s(2);
  HebiLookupEntryListPtr lookup_list = hebiLookupCreateLookupEntryList(lookup);

  // Go through the objects in the entry list
  int size = hebiLookupEntryListGetNumberOfEntries(lookup_list);
  int i;
  char buffer[101];
  for (i = 0; i < size; ++i)
  {
    memset(buffer, 0x00, 101 * sizeof(char));
    int res = hebiLookupEntryListGetName(lookup_list, i, buffer, 100);
    if (res == 0)
      printf("%02d: %s\n", i, buffer);
    else
      printf("Name could not fit in buffer!\n");
  }

  // Always delete objects after you are done with them.
  hebiLookupRelease(lookup);
  hebiCleanup();

  return 0;
}
